@@ -1,19 +1,23 @@
-# Copyright (c) 2012, 2016, Oracle and/or its affiliates. All rights reserved.
+# Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
 #
-# This program is free software; you can redistribute it and/or
-# modify it under the terms of the GNU General Public License as
-# published by the Free Software Foundation; version 2 of the
-# License.
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License, version 2.0,
+# as published by the Free Software Foundation.
 #
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU General Public License for more details.
+# This program is also distributed with certain software (including
+# but not limited to OpenSSL) that is licensed under separate terms, as
+# designated in a particular file or component or in included license
+# documentation.  The authors of MySQL hereby grant you an additional
+# permission to link the program and your derivative works with the
+# separately licensed software that they have included with MySQL.
+# This program is distributed in the hope that it will be useful,  but
+# WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+# the GNU General Public License, version 2.0, for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-# 02110-1301  USA
+# along with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 
 # import the wb module
 from wb import DefineModule
@@ -50,21 +54,22 @@ def apply_scripts_to_catalog(catalog, create_scripts, drop_scripts):
                 obj.temp_sql = "-- no script was generated for %s" % obj.name
     
     for schema in catalog.schemata:
+        delimiter = grt.root.wb.options.options['SqlDelimiter']
         apply_script(schema, create_scripts.get(schema.__id__, None), drop_scripts.get(schema.__id__, None))
         for table in schema.tables:
             apply_script(table, create_scripts.get(table.__id__, None))
             for trigger in table.triggers:
                 sql = create_scripts.get(trigger.__id__, None)
                 if sql:
-                    sql = "DELIMITER $$\n"+sql
-                apply_script(trigger, sql, delim="$$")
+                    sql = "DELIMITER " + delimiter + "\n" + sql
+                apply_script(trigger, sql, delim = delimiter)
         for view in schema.views:
             apply_script(view, create_scripts.get(view.__id__, None))
         for routine in schema.routines:
             sql = create_scripts.get(routine.__id__, None)
             if sql:
-                sql = "DELIMITER $$\n"+sql        
-            apply_script(routine, sql, delim="$$")
+                sql = "DELIMITER " + delimiter + "\n"+sql
+            apply_script(routine, sql, delim = delimiter)
 
 
 @ModuleInfo.export(grt.INT, grt.classes.db_mysql_Catalog, grt.classes.GrtVersion, grt.DICT)
@@ -410,7 +415,7 @@ def getOS(connection):
                 return 'linux'
             elif 'win' in compile_os:
                 return 'windows'
-            elif 'osx' in compile_os:
+            elif any(os in compile_os for os in ['osx', 'macos']):
                 return 'darwin'
 
     return None
