@@ -1,4 +1,4 @@
-# Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
+# Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2.0,
@@ -287,6 +287,7 @@ class SelectFileWizardPage(WizardPage):
 
         self.shapefile_browse_btn = newButton()
         self.shapefile_browse_btn.set_text("Browse...")
+        self.shapefile_browse_btn.set_name("Browse")
         self.shapefile_browse_btn.add_clicked_callback(self.shapefile_browse)
         entry_box.add(self.shapefile_browse_btn, False, True)
 
@@ -348,6 +349,7 @@ unless the append or update options are specified.""")
         
         self.warning_srs = mforms.newLabel("")
         self.content.add(self.warning_srs, False, True)
+        self.check_ogr_executables()
 
     def go_cancel(self):
         self.main.cancel()
@@ -367,7 +369,6 @@ unless the append or update options are specified.""")
             self.ogr2ogr_missing_lbl.show(True)
 
     def validate(self):
-        self.check_ogr_executables()
         if self.ogrinfo_missing or self.ogr2ogr_missing:
             mforms.Utilities.show_error("Missing Executable", "One of the required executables is missing. Please correct this before continue.", "OK", "", "")
             return False
@@ -592,21 +593,19 @@ class ImportProgressPage(WizardProgressPage):
     def __init__(self, owner):
         WizardProgressPage.__init__(self, owner, "Import Data")
 
-        self.add_task(self.prepare_import, "Prepare import")
-        self.add_threaded_task(self.start_import, "Import data file")
+        self.add_task(self.prepare_import, "Prepare import", "Prepare Import")
+        self.add_threaded_task(self.start_import, "Import data file", "Import Data File")
         self.importer_time = None
         self.importer = None
 
     def get_mysql_password(self, connection):
         parameterValues = connection.parameterValues
-        pwd = parameterValues["password"]
-        if not pwd:
-            username = parameterValues["userName"]
-            host = connection.hostIdentifier
-            title = "MySQL password for File Import"
-            accepted, pwd = mforms.Utilities.find_or_ask_for_password(title, host, username, False)
-            if not accepted:
-                return None
+        username = parameterValues["userName"]
+        host = connection.hostIdentifier
+        title = "MySQL password for File Import"
+        accepted, pwd = mforms.Utilities.find_or_ask_for_password(title, host, username, False)
+        if not accepted:
+            return None
         return pwd
     
     def page_activated(self, advancing):
