@@ -1,19 +1,23 @@
-# Copyright (c) 2009, 2015, Oracle and/or its affiliates. All rights reserved.
+# Copyright (c) 2009, 2019, Oracle and/or its affiliates. All rights reserved.
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License, version 2.0,
+# as published by the Free Software Foundation.
+#
+# This program is also distributed with certain software (including
+# but not limited to OpenSSL) that is licensed under separate terms, as
+# designated in a particular file or component or in included license
+# documentation.  The authors of MySQL hereby grant you an additional
+# permission to link the program and your derivative works with the
+# separately licensed software that they have included with MySQL.
+# This program is distributed in the hope that it will be useful,  but
+# WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+# the GNU General Public License, version 2.0, for more details.
 #
-# This program is free software; you can redistribute it and/or
-# modify it under the terms of the GNU General Public License as
-# published by the Free Software Foundation; version 2 of the
-# License.
-# 
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU General Public License for more details.
-# 
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-# 02110-1301  USA
+# along with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 
 import re
 import sys
@@ -32,12 +36,11 @@ import grt
 import mforms
 
 from grt import log_warning
-from workbench.log import log_info, log_error, log_debug, log_debug2
+from workbench.log import log_info, log_error, log_debug2
 import traceback
 
-from workbench.ui import WizardForm, WizardPage, WizardProgressPage
-from mforms import newButton, newCheckBox, newTreeNodeView
-from mforms import FileChooser
+from workbench.ui import WizardForm, WizardPage
+from mforms import newButton, newCheckBox
 
 # define this Python module as a GRT module
 ModuleInfo = DefineModule(name= "PyWbUtils", author= "Sun Microsystems Inc.", version="1.0")
@@ -61,7 +64,7 @@ def get_linux_terminal_program():
     return None
 
 
-@ModuleInfo.plugin('wb.tools.backupConnections', caption='Backup existing connections')
+@ModuleInfo.plugin('wb.tools.backupConnections', caption='Backup existing connections', accessibilityName="Backup Existing Connections")
 @ModuleInfo.export(grt.INT)
 def backupConnections():
     user_data_dir = mforms.App.get().get_user_data_folder()
@@ -93,7 +96,7 @@ def backupConnections():
     return 0
 
 
-@ModuleInfo.plugin('wb.tools.restoreConnections', caption='Restore connections from a backup file')
+@ModuleInfo.plugin('wb.tools.restoreConnections', caption='Restore connections from a backup file', accessibilityName="Restore Connections")
 @ModuleInfo.export(grt.INT)
 def restoreConnections():
     def generate_unique_name(name, name_set):
@@ -166,6 +169,8 @@ def restoreConnections():
             previous_instances_conns = set()
             duplicated_instance_count = 0
             for candidate_instance in instances:
+                if candidate_instance.connection is None:
+                    continue 
                 if candidate_instance.connection.__id__ in previous_instances_conns:
                     duplicated_instance_count = duplicated_instance_count + 1
                     continue  # Skip instances whose connections are associated to previously processed instances
@@ -276,7 +281,7 @@ def connectionFromString(connstr):
             try:
                 port = int(port)
             except:
-                log_warning("wb_utils", "Error parsing connstring, port value '%s' should be a number\n" % port)
+                log_warning("wb_utils", "Error parsing connstring; port value '%s' should be a number\n" % port)
                 port = None
         if not port:
             port = 3306
@@ -307,14 +312,14 @@ def connectionFromString(connstr):
     return None
 
 
-@ModuleInfo.plugin("wb.tools.copyConnectionString", caption="Copy Connection String to Clipboard", input= [wbinputs.selectedConnection()], pluginMenu="Home/Connections")
+@ModuleInfo.plugin("wb.tools.copyConnectionString", caption="Copy Connection String to Clipboard", input= [wbinputs.selectedConnection()], pluginMenu="Home/Connections", accessibilityName="Copy Connection String to Clipboard")
 @ModuleInfo.export(grt.INT, grt.classes.db_mgmt_Connection)
 def copyConnectionString(conn):
     connstr = connectionStringFromConnection(conn)
     mforms.Utilities.set_clipboard_text(connstr)
 
 
-@ModuleInfo.plugin("wb.tools.copyJDBCConnectionString", caption="Copy JDBC Connection String to Clipboard", input= [wbinputs.selectedConnection()], pluginMenu="Home/Connections")
+@ModuleInfo.plugin("wb.tools.copyJDBCConnectionString", caption="Copy JDBC Connection String to Clipboard", input= [wbinputs.selectedConnection()], pluginMenu="Home/Connections", accessibilityName="Copy JBDC String to Clipboard")
 @ModuleInfo.export(grt.INT, grt.classes.db_mgmt_Connection)
 def copyJDBCConnectionString(conn):
     if conn.parameterValues.has_key("schema"):
@@ -335,7 +340,7 @@ def copyJDBCConnectionString(conn):
     mforms.Utilities.set_clipboard_text(connstr+params)
 
 
-@ModuleInfo.plugin("wb.tools.createMissingLocalConnections", caption="Rescan for Local MySQL Instances", input= [], pluginMenu="Home/Connections")
+@ModuleInfo.plugin("wb.tools.createMissingLocalConnections", caption="Rescan for Local MySQL Instances", input= [], pluginMenu="Home/Connections", accessibilityName="Rescan MySQL Instances")
 @ModuleInfo.export(grt.INT)
 def createMissingLocalConnections():
 
@@ -352,7 +357,7 @@ def createMissingLocalConnections():
     
     return 1
 
-@ModuleInfo.plugin("wb.tools.connectionFromClipboard", caption="Add Connection(s) from Clipboard", input= [], pluginMenu="Home/Connections")
+@ModuleInfo.plugin("wb.tools.connectionFromClipboard", caption="Add Connection(s) from Clipboard", input= [], pluginMenu="Home/Connections", accessibilityName="Add Connections From Clipboard")
 @ModuleInfo.export(grt.INT)
 def newConnectionFromClipboard():
     text = mforms.Utilities.get_clipboard_text()
@@ -396,7 +401,7 @@ def newConnectionFromClipboard():
     return 1
 
 
-@ModuleInfo.plugin("wb.tools.cmdlineClient", caption="Start Command Line Client", input= [wbinputs.selectedConnection()], pluginMenu="Home/Connections")
+@ModuleInfo.plugin("wb.tools.cmdlineClient", caption="Start Command Line Client", input= [wbinputs.selectedConnection()], pluginMenu="Home/Connections", accessibilityName="Command Line Client")
 @ModuleInfo.export(grt.INT, grt.classes.db_mgmt_Connection)
 def startCommandLineClientForConnection(conn):
     import platform
@@ -455,12 +460,16 @@ def startCommandLineClientForConnection(conn):
         command = """\\"%s\\" \\"-u%s\\" \\"-h%s\\" -P%i %s -p %s""" % (bundled_client_path, user, host, port, socket, schema)
 
         # call mysql client in a loop until either: 1. it exits with no error, or 2. user exits with Ctrl+C.
-        # This is necessary because if the user enters wrong password, the window closes too quick for the user to see what's going on.
-        subprocess.call([ "/bin/sh", "-c",  # <--- having extra /bin/sh wrapper allows GUI terminal to be launched in background (thus run parallel with workbench)
-            get_linux_terminal_program() + " -e '" +
+        # This is necessary because if the user enters wrong password, the window closes too quick for the user to see what's going on.        
+        my_env = os.environ.copy()
+        if (("XDG_SESSION_TYPE" in my_env and my_env["XDG_SESSION_TYPE"] == "wayland") 
+          or "WAYLAND_DISPLAY" in my_env) and my_env["GDK_BACKEND"]:
+            my_env["GDK_BACKEND"] = "wayland"
+        subprocess.Popen(["/bin/sh", "-c",
+                          get_linux_terminal_program() + " -e '" +
                 "sh -c \"while :; do %s && break || read -p \\\"Press Enter to retry or Ctrl+C to quit\\\" DUMMY_VAR; done\" " % command
-            + "' &"   # <--- launch GUI terminal and exit (returns to Workbench immediately rather than blocking)
-        ])
+                + "' &"   # <--- launch GUI terminal and exit (returns to Workbench immediately rather than blocking) 
+        ], shell=False, env=my_env)
 
 if sys.platform == "linux2":
     @ModuleInfo.export(grt.INT)
@@ -512,7 +521,7 @@ def process_not_found_utils():
 
         mforms.Utilities.open_url(utilities_url)
 
-@ModuleInfo.plugin("wb.tools.utilitiesShell", caption="Start Shell for MySQL Utilities", groups=["Others/Menu/Ungrouped"])
+@ModuleInfo.plugin("wb.tools.utilitiesShell", caption="Start Shell for MySQL Utilities", groups=["Others/Menu/Ungrouped"], accessibilityName="MySQL Utilities Shell")
 @ModuleInfo.export(grt.INT)
 def startUtilitiesShell():
     import platform
@@ -562,7 +571,11 @@ def startUtilitiesShell():
                 if 'konsole' in term:
                     subprocess.call([term, "-e", "/bin/sh", setup_script])
                 else:
-                    subprocess.call(["/bin/sh", "-c", "%s -e %s &" % (term, setup_script)])
+                    my_env = os.environ.copy()
+                    if (("XDG_SESSION_TYPE" in my_env and my_env["XDG_SESSION_TYPE"] == "wayland") 
+                      or "WAYLAND_DISPLAY" in my_env) and my_env["GDK_BACKEND"]:
+                        my_env["GDK_BACKEND"] = "wayland"
+                    subprocess.Popen(["/bin/sh", "-c", "%s -e %s &" % (term, setup_script)], shell=False, env=my_env)
             else:
                 raise RuntimeError("Terminal program could not be found")
 
@@ -579,31 +592,151 @@ class CheckForUpdateThread(threading.Thread):
         
         self.is_running = True
         try:
-            import xml.dom.minidom
             import urllib2
-            
-            self.dom = xml.dom.minidom.parse(urllib2.urlopen('http://wb.mysql.com/installer/products.xml'))
+            import json
+            import base64
+
+            class LoginForm(mforms.Form):
+                def __init__(self):
+                    mforms.Form.__init__(self, None)
+
+                    self.set_title("Apply Changes to MySQL configuration File")
+                    content = mforms.newBox(False)
+                    content.set_padding(12)
+                    content.set_spacing(12)
+
+                    button_box = mforms.newBox(True)
+                    button_box.set_spacing(12)
+                    self.apply_btn = mforms.newButton()
+                    self.apply_btn.set_text("Apply")
+
+                    self.cancel_btn = mforms.newButton()
+                    self.cancel_btn.set_text("Cancel")
+                    self.cancel_btn.add_clicked_callback(self.cancel_clicked)
+
+                    content.add(button_box, False, True)
+                    self.set_content(content)
+                    self.set_size(640, 480)
+                    
+                    self.apply_btn.add_clicked_callback(self.apply_clicked)
+                    self.cancel_btn.add_clicked_callback(self.cancel_clicked)
+
+                def show(self):
+                    self.run_modal(self.apply_btn, self.cancel_btn)
+                def apply_clicked(self):
+                    self.close()
+
+                def cancel_clicked(self):
+                    self.close()
+
+            class ProxyAuthenticationHandler(urllib2.AbstractBasicAuthHandler, urllib2.BaseHandler):
+
+                auth_header = 'Proxy-authorization'
+                attempts = 0
+                
+                class ProxyAuthenticationForm(mforms.Form):
+                    def __init__(self):
+                        mforms.Form.__init__(self, None, mforms.FormDialogFrame)
+                        self.set_size(400, -1)
+
+                        box = mforms.newBox(False)
+                        box.set_spacing(12)
+                        box.set_padding(12)
+
+                        self.set_content(box)
+                        self.set_title("Proxy Authentication")
+
+                        content = mforms.newTable()
+
+                        content.set_padding(12);
+                        content.set_row_count(2);
+                        content.set_row_spacing(10);
+                        content.set_column_count(2);
+                        content.set_column_spacing(10);
+
+                        self.username = mforms.newTextEntry()
+                        self.password = mforms.newTextEntry(mforms.PasswordEntry)
+
+                        content.add(mforms.newLabel("User Name:"), 0, 1, 0, 1, mforms.HFillFlag | mforms.VFillFlag);
+                        content.add(self.username, 1, 2, 0, 1, mforms.HFillFlag | mforms.HExpandFlag);
+                        content.add(mforms.newLabel("Password:"), 0, 1, 1, 2, mforms.HFillFlag | mforms.VFillFlag);
+                        content.add(self.password, 1, 2, 1, 2, mforms.HFillFlag | mforms.HExpandFlag);
+
+                        box.add(content, True, True)
+
+                        self.ok = mforms.newButton()
+                        self.ok.set_text("OK")
+                        self.cancel = mforms.newButton()
+                        self.cancel.set_text("Cancel")
+                        button_box = mforms.newBox(True)
+                        mforms.Utilities.add_end_ok_cancel_buttons(button_box, self.ok, self.cancel)
+                        box.add_end(button_box, False, True)
+
+                        self.ok.add_clicked_callback(self.accepted)
+                        self.cancel.add_clicked_callback(self.canceled)
+                    def run(self):
+                        return self.run_modal(None, self.cancel)
+                    
+                    def accepted(self):
+                        self.end_modal(True)
+                    def canceled(self):
+                        self.end_modal(False)
+
+
+                def request_authentication(self):
+                    dialog = self.ProxyAuthenticationForm()
+                    self.result = dialog.run()
+                    self.username = dialog.username.get_string_value()
+                    self.password = dialog.password.get_string_value()
+
+                def http_error_407(self, req, fp, code, msg, headers):
+                    authority = req.host
+
+                    if self.attempts > 0:
+                        mforms.Utilities.show_error('Proxy Authentication', 'The proxy authentication was incorrect. Please try again.', "OK", "", "")
+
+                    mforms.Utilities.perform_from_main_thread(self.request_authentication, True)
+
+                    if self.result == False:
+                        return None
+
+                    self.attempts = self.attempts + 1
+
+                    raw = "%s:%s" % (self.username, self.password)
+                    auth = "Basic " + base64.b64encode(raw.encode()).decode("ascii")
+                    if req.get_header(self.auth_header, None) == auth:
+                        return None
+                    req.add_unredirected_header(self.auth_header, auth)
+
+                    return self.parent.open(req, timeout=req.timeout)
+
+            proxy_handler = urllib2.ProxyHandler()
+            proxy_auth_handler = ProxyAuthenticationHandler()
+
+            opener = urllib2.build_opener()
+            opener.add_handler(proxy_handler)
+            opener.add_handler(proxy_auth_handler)
+
+            urllib2.install_opener(opener)
+
+            self.json = json.load(urllib2.urlopen("http://workbench.mysql.com/current-release")) 
         except Exception, error:
-            self.dom = None
-            self.error = "%s\n\nPlease verify your internet connection is available." % str(error)        
+
+            self.json = None
+            self.error = "%s\n\nPlease verify that your internet connection is available." % str(error)        
     
     def checkForUpdatesCallback(self):
         if self.isAlive():
             return True  # Don't do anything until the dom is built
         
-        if not self.dom:
+        if not self.json:
             if hasattr(self, 'error'):
                 mforms.Utilities.show_error("Check for updates failed", str(self.error), "OK", "", "")
         else:
             try:
                 current_version = (grt.root.wb.info.version.majorNumber, grt.root.wb.info.version.minorNumber, grt.root.wb.info.version.releaseNumber)
-                edition = '' if grt.root.wb.info.license == 'GPL' else '-commercial'
-                filename=u'mysql-workbench' + (edition or '-community')
-                packages = ( package for package in self.dom.getElementsByTagName('Package') if package.parentNode.parentNode.attributes['name'].nodeValue == u'workbench-win32' + edition)
-                version_strings = (node.attributes['thisVersion'].nodeValue for node in packages if node.attributes['filename'].nodeValue.startswith(filename) and node.attributes['filename'].nodeValue.endswith(u'msi'))
-                versions = tuple( tuple( int(num) for num in version_string.split('.') ) for version_string in version_strings )
-                version_list = [v for v in versions]
-                newest_version = max( version_list ) if version_list else current_version
+                newest_version = tuple(int(i) for i in self.json['fullversion'].split("."))
+
                 if newest_version > current_version:
                     if mforms.Utilities.show_message('New Version Available', 'The new MySQL Workbench %s has been released.\nYou can download the latest version from\nhttp://www.mysql.com/downloads/workbench.' % '.'.join( [str(num) for num in newest_version] ),
                                                   'Get it Now', 'Maybe Later', "") == mforms.ResultOk:
@@ -623,7 +756,7 @@ class CheckForUpdateThread(threading.Thread):
 # Global variable:
 thread = CheckForUpdateThread()
 
-@ModuleInfo.plugin("wb.tools.checkForUpdates", caption="Check for Updates")
+@ModuleInfo.plugin("wb.tools.checkForUpdates", caption="Check for Updates", accessibilityName="Check for Updates")
 @ModuleInfo.export(grt.INT)
 def checkForUpdates():
     global thread
@@ -797,7 +930,7 @@ class SSLWizard_IntroPage(WizardPage):
         box.set_padding(20)
         box.set_spacing(20)
 
-        message = "This wizard will assist you generating a set of SSL certificates and self-signed keys that are required \n"
+        message = "This wizard will assist you to generate a set of SSL certificates and self-signed keys that are required \n"
         message += "by the MySQL server to enable SSL. Other files will also be generated so that you can check how to \n"
         message += "configure your server and clients as well as the attributes used to generate them."
 
@@ -825,7 +958,7 @@ class SSLWizard_OptionsPage(WizardPage):
         self.use_default_parameters.set_active(False)
         
         self.clear_button = newButton()
-        self.clear_button.set_text("Clear")
+        self.clear_button.set_text("Clear Files")
         self.clear_button.add_clicked_callback(self.clear_button_clicked)
         self.clear_button.set_enabled(os.path.isdir(self.main.results_path))
 
@@ -863,30 +996,36 @@ class SSLWizard_OptionsPage(WizardPage):
         box.set_spacing(12)
         box.set_padding(12)
 
-        message = "These optons allow you to configure the process. You can use default parameters\n"
-        message += "instead providing your own, allow the generation of the certifcates and determine\n"
-        message += "whether to uptade the connection settings or not."
+        message = "These options allow you to configure the process. You can use default parameters\n"
+        message += "instead of providing your own, allow the generation of the certificates and determine\n"
+        message += "whether to update the connection settings or not."
 
         label = mforms.newLabel(message)
 
-        box.add(label, False, False)
-        box.add(self.use_default_parameters, False, False)
-        box.add(self.generate_files, False, False)
-        box.add(self.update_connection, False, False)
+        box.add(label, False, True)
+        box.add(self.use_default_parameters, False, True)
+        box.add(self.generate_files, False, True)
+        box.add(self.update_connection, False, True)
         
-        self.content.add(box, False, False)
-        self.content.add(self.clear_button, False, False)
+        button_box = mforms.newBox(True)
+        button_box.set_spacing(12)
+        button_box.set_padding(12)
+        
+        button_box.add(self.clear_button, False, True)
+        
+        self.content.add(box, False, True)
+        self.content.add(button_box, False, True)
         box.show(True)
 
 class SSLWizard_GeneratePage(WizardPage):
     def __init__(self, owner):
         WizardPage.__init__(self, owner, "Generate certificates and self-signed keys")
 
-        self.ca_cert = os.path.join(self.main.results_path, "ca-cert.pem")
-        self.server_cert = os.path.join(self.main.results_path, "server-cert.pem")
-        self.server_key = os.path.join(self.main.results_path, "server-key.pem")
-        self.client_cert = os.path.join(self.main.results_path, "client-cert.pem")
-        self.client_key = os.path.join(self.main.results_path, "client-key.pem")
+        self.ca_cert = os.path.join(self.main.results_path, "ca-cert.pem").replace('\\', '/')
+        self.server_cert = os.path.join(self.main.results_path, "server-cert.pem").replace('\\', '/')
+        self.server_key = os.path.join(self.main.results_path, "server-key.pem").replace('\\', '/')
+        self.client_cert = os.path.join(self.main.results_path, "client-cert.pem").replace('\\', '/')
+        self.client_key = os.path.join(self.main.results_path, "client-key.pem").replace('\\', '/')
 
         self.table = mforms.newTable()
         self.table.set_padding(12)
@@ -905,7 +1044,7 @@ class SSLWizard_GeneratePage(WizardPage):
         row, self.common_name = self.add_label_row(row, "Common:", "eg, put the FQDN of the server\nto allow server address validation")
 
         message = "Now you must specify the parameters to use in the certificates and self-signed key generation.\n"
-        message += "This may include some data refering youself and/or the company you work for. All fields are optional."
+        message += "This may include some data refering to youself and/or the company you work for. All fields are optional."
         
         self.parameters_box = mforms.newBox(False)
         self.parameters_box.set_padding(20)
@@ -917,8 +1056,8 @@ class SSLWizard_GeneratePage(WizardPage):
         self.parameters_panel.set_title("Optional Parameters")
         self.parameters_panel.add(self.table)
         
-        self.parameters_box.add(self.parameters_label, False, False)
-        self.parameters_box.add(self.parameters_panel, False, False)
+        self.parameters_box.add(self.parameters_label, False, True)
+        self.parameters_box.add(self.parameters_panel, False, True)
 
         self.default_label = mforms.newLabel("The wizard is ready to generate the files for you. Click 'Next >' to generate \nthe certificates and self-signed key files...")
 
@@ -984,11 +1123,11 @@ ssl-key=%(client_key)s
 ssl-ca=%(ca_cert)s
 ssl-cert=%(server_cert)s
 ssl-key=%(server_key)s
-        """ % {"ca_cert"     : os.path.join("<directory>", os.path.basename(self.ca_cert)), 
-               "server_cert" : os.path.join("<directory>", os.path.basename(self.server_cert)), 
-               "server_key"  : os.path.join("<directory>", os.path.basename(self.server_key)), 
-               "client_cert" : os.path.join("<directory>", os.path.basename(self.client_cert)), 
-               "client_key"  : os.path.join("<directory>", os.path.basename(self.client_key))
+        """ % {"ca_cert"     : os.path.join("<directory>", os.path.basename(self.ca_cert)).replace('\\', '/'), 
+               "server_cert" : os.path.join("<directory>", os.path.basename(self.server_cert)).replace('\\', '/'), 
+               "server_key"  : os.path.join("<directory>", os.path.basename(self.server_key)).replace('\\', '/'), 
+               "client_cert" : os.path.join("<directory>", os.path.basename(self.client_cert)).replace('\\', '/'), 
+               "client_key"  : os.path.join("<directory>", os.path.basename(self.client_key)).replace('\\', '/')
               })
         f.close()
         log_debug2("SSL Wizard generation task result: %s\n" % str(task.result))
@@ -1006,24 +1145,24 @@ class SSLWizard_ResultsPage(WizardPage):
 
     def go_next(self):
         if self.update_connection:
-            self.main.conn.parameterValues['sslCA'] = self.main.generate_page.ca_cert
-            self.main.conn.parameterValues['sslCert'] = self.main.generate_page.client_cert
-            self.main.conn.parameterValues['sslKey'] = self.main.generate_page.client_key
-            self.main.conn.parameterValues['useSSL'] = 2
+            self.main.conn.parameterValues['sslCA'] = self.main.generate_page.ca_cert.replace('\\', '/')
+            self.main.conn.parameterValues['sslCert'] = self.main.generate_page.client_cert.replace('\\', '/')
+            self.main.conn.parameterValues['sslKey'] = self.main.generate_page.client_key.replace('\\', '/')
+            self.main.conn.parameterValues['useSSL'] = 4
             
         self.main.go_next_page()
 
     def create_ui(self):
       
-        message = "The wizard was sucessful. "
+        message = "The wizard was successful. "
         
         if self.update_connection:
             message += "Click on the finish button to update the connection. "
             
         message += "To setup the server, you should \ncopy the following files to a <directory> inside %s:\n\n" % self.main.conn.parameterValues['hostName']
-        message += " - %s\n" % str(os.path.join(self.main.results_path, "ca_cert"))
-        message += " - %s\n" % str(os.path.join(self.main.results_path, "server_cert"))
-        message += " - %s\n" % str(os.path.join(self.main.results_path, "server_key"))
+        message += " - %s\n" % str(os.path.join(self.main.results_path, "ca-cert.pem")).replace('\\', '/')
+        message += " - %s\n" % str(os.path.join(self.main.results_path, "server-cert.pem")).replace('\\', '/')
+        message += " - %s\n" % str(os.path.join(self.main.results_path, "server-key.pem")).replace('\\', '/')
         message += "\n\nand edit the config file to use the following parameters:"
         
         label = mforms.newLabel(message)
@@ -1036,7 +1175,7 @@ class SSLWizard_ResultsPage(WizardPage):
         self.content.add(config_file, False, True)
         f.close()
         
-        label = mforms.newLabel("A copy of this file can be found in:\n%s" % str(os.path.join(self.main.results_path, "my.cnf.sample")))
+        label = mforms.newLabel("A copy of this file can be found in:\n%s" % str(os.path.join(self.main.results_path, "my.cnf.sample").replace('\\', '/')))
         self.content.add(label, False, True)
         
         return
